==> bootstrap_horizontal_tabs-8.x-1.1.tar.gz: bootstrap_horizontal_tabs/src/Plugin/Field/FieldWidget/BootstrapHorizontalTabs.php <==
<?php

namespace Drupal\bootstrap_horizontal_tabs\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'bootstrap_horizontal_tabs' widget.
 *
 * @FieldWidget(
 *   id = "bootstrap_horizontal_tabs",
 *   label = @Translation("Horizontal Tabs"),
 *   field_types = {
 *     "bootstrap_horizontal_tabs"
 *   }
 * )
 */
class BootstrapHorizontalTabs extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['header'] = [
      '#title' => 'Tab Label',
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->header) ? $items[$delta]->header : NULL,
      '#size' => '60',
      '#placeholder' => '',
      '#maxlength' => 255,
    ];
    $element['body'] = [
      '#title' => 'Tab Body',
      '#type' => 'text_format',
      '#default_value' => isset($items[$delta]->body_value) ? $items[$delta]->body_value : NULL,
      '#format' => $items[$delta]->body_format,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function extractFormValues(FieldItemListInterface $items, array $form, FormStateInterface $form_state) {
    parent::extractFormValues($items, $form, $form_state);
    $tabs = $items->getValue();
    $field_name = $items->getName();
    // Loop through tab deltas.
    foreach ($tabs as $delta => $tab) {
      // If header is emtpy and body is not, set error.
      if (empty($tab['header']) && !empty($tab['body_value'])) {
        $form_state->setError($form[$field_name]['widget'][$delta]['header'], $this->t("A tab label must be provided for tab body content. Hint: body content may include 'invisible' characters such as spaces or HTML markup."));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    // This loop is through (potential) field instances.
    foreach ($values as &$value) {
      // Split the "text_format" form element data into our field's schema.
      $value['body_value'] = $value['body']['value'];
      $value['body_format'] = $value['body']['format'];
    }
    return $values;
  }

}

==> bootstrap_horizontal_tabs-8.x-1.3.tar.gz: bootstrap_horizontal_tabs/src/Plugin/Field/FieldWidget/BootstrapHorizontalTabs.php <==
<?php

namespace Drupal\bootstrap_horizontal_tabs\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Plugin implementation of the 'bootstrap_horizontal_tabs' widget.
 *
 * @FieldWidget(
 *   id = "bootstrap_horizontal_tabs",
 *   label = @Translation("Horizontal Tabs"),
 *   field_types = {
 *     "bootstrap_horizontal_tabs"
 *   }
 * )
 */
class BootstrapHorizontalTabs extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['header'] = [
      '#title' => 'Tab Label',
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->header) ? $items[$delta]->header : NULL,
      '#size' => '60',
      '#placeholder' => '',
      '#maxlength' => 255,
    ];
    $element['body'] = [
      '#title' => 'Tab Body',
      '#type' => 'text_format',
      '#default_value' => isset($items[$delta]->body_value) ? $items[$delta]->body_value : NULL,
      '#format' => $items[$delta]->body_format,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    // This loop is through (potential) field instances.
    foreach ($values as &$value) {
      // Split the "text_format" form element data into our field's schema.
      $value['body_value'] = $value['body']['value'];
      $value['body_format'] = $value['body']['format'];
    }
    return $values;
  }

  /**
   * {@inheritdoc}
   *
   * @see Drupal\text\Plugin\Field\FieldWidget\TextareaWithSummaryWidget.php
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    $element = parent::errorElement($element, $violation, $form, $form_state);
    return ($element === FALSE) ? FALSE : $element[$violation->arrayPropertyPath[0]];
  }

}
